Pytilities is a python3 utility library for developers.

Links
=====

- `Pytilities homepage`_
- `Documentation`_


Features
========

- Aspect oriented programming: 

  - Give advice to class/instance descriptors (i.e. methods, properties, ...)
  - Use aspects to create new attributes on classes/instances
- Event dispatching: Observer/Subject like event dispatching with wrappers
  for hiding events on dispatchers and combining dispatchers
- Function overloading
- Basic geometry: Vector, Rectangle classes
- Various: cross platform infinity number, ...


.. _Pytilities homepage: http://pytilities.sourceforge.net/
.. _Documentation: http://pytilities.sourceforge.net/doc/1.0.0/
